package com.ruoyi.web.controller.system.count;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TdPropertyInfo;
import com.ruoyi.system.domain.TdPropertyNet;
import com.ruoyi.system.domain.TdPropertyNetinfo;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.system.service.ITdPropertyNetService;
import com.ruoyi.system.service.ITdPropertyNetinfoService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;

@Controller
@RequestMapping("/system/networknum")
public class SysNetworknumController extends BaseController {
    private String prefix = "system/network/networknum";

    @Autowired
    private ITdPropertyNetService tdPropertyNetService;
    @Autowired
    private ITdPropertyNetinfoService tdPropertyNetinfoService;

    @RequiresPermissions("system:networknum:view")
    @GetMapping()
    public String network()
    {
        return prefix + "/networknum";
    }

    /**
     * 查询涉密网络设备列表
     */
    @RequiresPermissions("system:networknum:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdPropertyNet tdPropertyNet)
    {
        startPage();
        List<TdPropertyNet> list = tdPropertyNetService.selectTdPropertyNetList(tdPropertyNet);
        return getDataTable(list);
    }

    /**
     * 打印界面
     */
    @RequiresPermissions("system:networknum:print")
    @GetMapping("/print/{netId}")
    @Log(title = "网络设备统计", businessType = BusinessType.PRINT)
    public String print(@PathVariable("netId") String netId, ModelMap mmap)
    {
        List<TdPropertyNetinfo> tdPropertyNetinfos = tdPropertyNetinfoService.selectTdPropertyNetinfoByNetId(netId);
        TdPropertyNet tdPropertyNet = tdPropertyNetService.selectTdPropertyNetByNetId(netId);
        mmap.put("tdPropertyNetinfos", tdPropertyNetinfos);
        mmap.put("tdPropertyNet", tdPropertyNet);
        mmap.put("sysuser", getSysUser());
        return prefix + "/print";
    }

    /**
     * 
     *  网络设备种类统计
     * @param null
     * @return 
     */
    
    @Autowired
    private ISysDictDataService dictDataService;
    @PostMapping("/countNetInfo")
    @ResponseBody
    public AjaxResult countNetInfo() {
        SysDictData sysDictData =  new SysDictData();
        sysDictData.setDictType("sys_net_type");
        List<SysDictData> smType = dictDataService.selectDictDataList(sysDictData);
        List<String> list = smType.stream().map(SysDictData::getDictLabel).collect(Collectors.toList());
        List<Long> yAxisData = new ArrayList<>();
        smType.forEach(xAxis -> {
            AtomicReference<Long> yAxis = new AtomicReference<>(0L);
            Integer count = tdPropertyNetinfoService.lambdaQuery()
                    .eq(TdPropertyNetinfo::getNetName, xAxis.getDictValue())
                    .count();
            yAxis.set(Long.valueOf(count));
            yAxisData.add(yAxis.get());
        });
        JSONObject obj = new JSONObject();
        obj.put("xAxisData", list.toArray());
        obj.put("yAxisData", yAxisData);
        return AjaxResult.success(obj);
    }


    /**
     *
     *  网络终端数统计
     * @return
     */

    @PostMapping("/countInfo")
    @ResponseBody
    public AjaxResult countInfo() {
        SysDictData sysDictData =  new SysDictData();
        sysDictData.setDictType("sys_file_miji");
        List<SysDictData> smType = dictDataService.selectDictDataList(sysDictData);
        List<String> list = smType.stream().map(SysDictData::getDictLabel).collect(Collectors.toList());
        List<Long> yAxisData = new ArrayList<>();
        smType.forEach(xAxis -> {
            AtomicReference<Long> yAxis = new AtomicReference<>(0L);
            Integer count = tdPropertyNetService.selectCountMi(xAxis.getDictValue());
            if(Objects.isNull(count)){
                count = 0;
            }
            yAxis.set(Long.valueOf(count));
            yAxisData.add(yAxis.get());
        });
        JSONObject obj = new JSONObject();
        obj.put("xAxisData", list.toArray());
        obj.put("yAxisData", yAxisData);
        return AjaxResult.success(obj);
    }

}
